# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_payments', '0003_auto_20160824_1459'),
    ]

    operations = [
        migrations.AlterField(
            model_name='currency',
            name='name',
            field=models.CharField(unique=True, max_length=15, verbose_name='Name'),
        ),
        migrations.AlterField(
            model_name='currency',
            name='price',
            field=models.FloatField(verbose_name='Price'),
        ),
        migrations.AlterField(
            model_name='currency',
            name='symbol',
            field=models.CharField(unique=True, max_length=2, verbose_name='Symbol'),
        ),
        migrations.AlterField(
            model_name='paymentanswer',
            name='answer',
            field=models.TextField(null=True, verbose_name='Answer', blank=True),
        ),
        migrations.AlterField(
            model_name='paymentanswer',
            name='answer_date',
            field=models.DateTimeField(verbose_name='Answer date', null=True, editable=False, blank=True),
        ),
        migrations.AlterField(
            model_name='paymentanswer',
            name='error_txt',
            field=models.TextField(null=True, verbose_name='Error Text', blank=True),
        ),
        migrations.AlterField(
            model_name='paymentanswer',
            name='ref',
            field=models.CharField(default=None, max_length=50, null=True, verbose_name='Reference'),
        ),
        migrations.AlterField(
            model_name='paymentanswer',
            name='request',
            field=models.TextField(null=True, verbose_name='Request', blank=True),
        ),
        migrations.AlterField(
            model_name='paymentanswer',
            name='request_date',
            field=models.DateTimeField(verbose_name='Request date', null=True, editable=False, blank=True),
        ),
        migrations.AlterField(
            model_name='paymentconfirmation',
            name='action',
            field=models.CharField(max_length=7, verbose_name='Action', choices=[(b'confirm', 'Confirm'), (b'cancel', 'Cancel')]),
        ),
        migrations.AlterField(
            model_name='paymentconfirmation',
            name='data',
            field=models.TextField(null=True, verbose_name='Data', blank=True),
        ),
        migrations.AlterField(
            model_name='paymentconfirmation',
            name='ref',
            field=models.CharField(max_length=50, verbose_name='Reference'),
        ),
        migrations.AlterField(
            model_name='paymentrequest',
            name='answer',
            field=models.TextField(null=True, verbose_name='Answer', blank=True),
        ),
        migrations.AlterField(
            model_name='paymentrequest',
            name='answer_date',
            field=models.DateTimeField(verbose_name='Answer date', null=True, editable=False, blank=True),
        ),
        migrations.AlterField(
            model_name='paymentrequest',
            name='cancelled',
            field=models.BooleanField(default=False, verbose_name='Cancelled'),
        ),
        migrations.AlterField(
            model_name='paymentrequest',
            name='error_txt',
            field=models.TextField(null=True, verbose_name='Error Text', blank=True),
        ),
        migrations.AlterField(
            model_name='paymentrequest',
            name='notes',
            field=models.CharField(max_length=30, null=True, verbose_name='Notes', blank=True),
        ),
        migrations.AlterField(
            model_name='paymentrequest',
            name='platform',
            field=models.CharField(max_length=20, verbose_name='Platform', choices=[(b'redsys', b'Redsys')]),
        ),
        migrations.AlterField(
            model_name='paymentrequest',
            name='protocol',
            field=models.CharField(max_length=10, verbose_name='Protocol', choices=[(b'paypal', 'Paypal'), (b'redsys', 'Redsys'), (b'redsysxml', 'Redsys XML')]),
        ),
        migrations.AlterField(
            model_name='paymentrequest',
            name='ref',
            field=models.CharField(max_length=50, verbose_name='Reference'),
        ),
        migrations.AlterField(
            model_name='paymentrequest',
            name='request',
            field=models.TextField(null=True, verbose_name='Request', blank=True),
        ),
        migrations.AlterField(
            model_name='paymentrequest',
            name='request_date',
            field=models.DateTimeField(verbose_name='Request date', null=True, editable=False, blank=True),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_payments', '0010_merge'),
    ]

    operations = [
        migrations.AlterField(
            model_name='paymentrequest',
            name='platform',
            field=models.CharField(max_length=20, verbose_name='Platform'),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_payments', '0002_auto_20160824_0950'),
    ]

    operations = [
        migrations.AlterField(
            model_name='paymentconfirmation',
            name='action',
            field=models.CharField(max_length=7, verbose_name='Acci\xf3n', choices=[(b'confirm', 'Confirmada'), (b'cancel', 'Cancelar')]),
        ),
        migrations.AlterField(
            model_name='paymentrequest',
            name='platform',
            field=models.CharField(max_length=20, verbose_name='Plataforma', choices=[(b'url', b'Url'), (b'real', b'Real'), (b'paypalonline', b'Paypalonline'), (b'name', b'Name'), (b'taxes', b'Taxes')]),
        ),
        migrations.AlterField(
            model_name='paymentrequest',
            name='protocol',
            field=models.CharField(max_length=10, verbose_name='Protocolo', choices=[(b'paypal', 'Paypal'), (b'redsys', 'Redsys'), (b'redsysxml', 'Redsys XML')]),
        ),
    ]



# -*- coding: utf-8 -*-
#
# django-codenerix-payments
#
# Copyright 2017 Centrologic Computational Logistic Center S.L.
#
# Project URL : http://www.codenerix.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from django.utils.translation import ugettext as _

from codenerix.forms import GenModelForm
from codenerix_payments.models import PaymentRequest


class PaymentRequestForm(GenModelForm):
    class Meta:
        model = PaymentRequest
        exclude = [
            'locator',
            'ref',
            'order',
            'reverse',
            'currency',
            'protocol',
            'real',
            'error',
            'error_txt',
            'cancelled',
            'request',
            'answer']
        autofill = {
            'platform': ['select', 3, 'CDNX_payments_platforms'],
        }

    def __groups__(self):
        g = [
            (_('Details'), 12,
                ['total', 6],
                ['platform', 6],
                ['notes', 12],)
        ]
        return g


class PaymentRequestUpdateForm(GenModelForm):
    class Meta:
        model = PaymentRequest
        exclude = [
            'total',
            'ref',
            'platform',
            'locator',
            'order',
            'reverse',
            'currency',
            'protocol',
            'real',
            'error',
            'error_txt',
            'cancelled',
            'request',
            'answer']

    def __groups__(self):
        g = [
            (_('Details'), 12,
                ['notes', 12],)
        ]
        return g



import os
from setuptools import setup

import codenerix_payments

with open(os.path.join(os.path.dirname(__file__), 'README.rst')) as readme:
    README = readme.read()

# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='django-codenerix-payments',
    version=codenerix_payments.__version__,
    packages=["codenerix_payments"],
    include_package_data=True,
    zip_safe=False,
    license='Apache License Version 2.0',
    description='Codenerix Payments is a module that enables CODENERIX to manage payments and let clients to pay online.',
    long_description=README,
    url='https://github.com/centrologic/django-codenerix-payments',
    author=", ".join(codenerix_payments.__authors__),
    keywords=['django', 'codenerix', 'management', 'erp', 'crm', 'payments', ],
    platforms=['OS Independent'],
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Framework :: Django :: 1.8',
        'Framework :: Django :: 1.9',
        'Framework :: Django :: 1.10',
        'Intended Audience :: Developers',
        'License :: Other/Proprietary License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Topic :: Internet :: WWW/HTTP',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
    ],
    install_requires=[
        'django-codenerix',
        'paypalrestsdk',
        'pycrypto',
    ]
)



# -*- coding: utf-8 -*-
#
# django-codenerix-payments
#
# Copyright 2017 Centrologic Computational Logistic Center S.L.
#
# Project URL : http://www.codenerix.com
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from django.conf.urls import url

from codenerix_payments.views import PaymentRequestList, PaymentRequestCreate, PaymentRequestUpdate, PaymentRequestDelete, \
    PaymentConfirmationList, PaymentAnswerList, PaymentAction, \
    PaymentRequestDetail, PaymentConfirmationDetail, PaymentAnswerDetail, PaymentPlatforms, PaymentConfirmationAutorender


urlpatterns = [
    url(r'^paymentrequests$', PaymentRequestList.as_view(), name='paymentrequest_list'),
    url(r'^paymentrequests/add$', PaymentRequestCreate.as_view(), name='paymentrequest_add'),
    url(r'^paymentrequests/(?P<pk>\w+)$', PaymentRequestDetail.as_view(), name='paymentrequest_detail'),
    url(r'^paymentrequests/(?P<pk>\w+)/edit$', PaymentRequestUpdate.as_view(), name='paymentrequest_edit'),
    url(r'^paymentrequests/(?P<pk>\w+)/delete$', PaymentRequestDelete.as_view(), name='paymentrequest_delete'),
    url(r'^paymentconfirmations$', PaymentConfirmationList.as_view(), name='paymentconfirmation_list'),
    url(r'^paymentconfirmations/(?P<pk>\w+)$', PaymentConfirmationDetail.as_view(), name='paymentconfirmation_detail'),
    url(r'^paymentanswers$', PaymentAnswerList.as_view(), name='paymentanswer_list'),
    url(r'^paymentanswers/(?P<pk>\w+)$', PaymentAnswerDetail.as_view(), name='paymentanswer_detail'),
    url(r'^action/(?P<locator>[a-zA-Z0-9+/]+)/(?P<action>\w+)/$', PaymentAction.as_view(), name='payment_url'),
    url(r'^platforms/(?P<search>[\w\W]+|\*)$', PaymentPlatforms.as_view(), name='CDNX_payments_platforms'),
    url(r'^confirmation/(?P<locator>[a-zA-Z0-9+/]+)/(?P<action>\w+)/(?P<error>\w+)$', PaymentConfirmationAutorender.as_view(), name='CNDX_payments_confirmation'),
]
